/* Look & feel */
:root {
  --btn-red: #ef4f39;
  --btn-red-bottom: #b94434;
  --btn-green: #3ba60a;
  --btn-green-bottom: #338a0d;
  --btn-blue: #009ee8;
  --btn-blue-bottom: #26789f;
  --btn-gray: #444;
  --btn-gray-bottom: #555;
  --bg-black: #231f20;
  --border-radius: 3px;
  --body-padding: 0.5rem;

  font-size: 100%;
  font-family: "Ubuntu", sans-serif;
  overflow-y: scroll;
}

h1 {
  margin-top: 1rem;
  margin-bottom: 0.5rem;
  font-size: 2rem;
  font-weight: bold;
}

table {
  border-collapse: collapse;
}
td,
th {
  border: 1px solid black;
  padding: 0.5em;
}
tr:nth-child(even) {
  background-color: #eee;
}
th {
  background-color: #777;
  color: white;
}

input {
  padding: 0.3rem;
}

.button {
  display: inline-block;
  user-select: none;
  margin: 0;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  vertical-align: bottom;

  cursor: pointer;
  border: 0;
  padding: 0.5rem 1rem 0.3rem 1rem;
  border-radius: var(--border-radius);
  color: white;
  text-decoration: none;
}
.button > * {
  margin-right: 0.3rem;
}
.button > *:last-child {
  margin-right: 0;
}
.button:hover {
  filter: brightness(110%);
}
.button:active {
  filter: brightness(90%);
}
.button:focus {
  box-shadow: 0 0 2px black;
}
.button.red {
  background-color: var(--btn-red);
  border-bottom: 4px solid var(--btn-red-bottom);
}
.button.green {
  background-color: var(--btn-green);
  border-bottom: 4px solid var(--btn-green-bottom);
}
.button.blue {
  background-color: var(--btn-blue);
  border-bottom: 4px solid var(--btn-blue-bottom);
}
.button.gray {
  background-color: var(--btn-gray);
  border-bottom: 4px solid var(--btn-gray-bottom);
}
.button.disabled,
.button.disabled:hover,
.button.disabled:active {
  background-color: #aaa;
  border-bottom: 4px solid #aaa;
  filter: none;
  cursor: default;
  opacity: 0.5;
}
.button > img {
  height: 1rem;
}

/* Grid layout */

nav {
  display: flex;
  flex-wrap: wrap;
  padding: var(--body-padding);
}
nav > * {
  margin-right: 1rem;
  margin-top: 0.2rem;
  margin-bottom: 0.2rem;
}
nav > *:last-child {
  margin-right: 0;
}

.logo {
  width: 150px;
}
.logo img {
  max-width: 100%;
  display: block;
}

.search {
  display: flex;
}

.links {
  margin-left: auto; /* to pull to the right */
  display: inline-flex;
  justify-content: center;
  align-items: center;
  color: white;
}
.links > * {
  margin-right: 1rem;
}
.links > *:last-child {
  margin-right: 0;
}
.links a * {
  vertical-align: middle;
}

/* Component-specific styling */

nav {
  background-color: var(--bg-black);
}

.search input {
  border: 0;
  border-radius: var(--border-radius) 0 0 var(--border-radius);
}
.search button {
  border-radius: 0 var(--border-radius) var(--border-radius) 0;
}

.links a {
  color: white;
  text-decoration: none;
}
.links a:hover {
  text-decoration: underline;
}

.content {
  margin: auto;
  padding: var(--body-padding);
}
.content > * {
  display: block;
  margin-top: 0.5rem;
  margin-bottom: 0.5rem;
}
